containertools.delete_contents_of_container_starting_at_or_after_offset
=======================================================================

.. autofunction:: abjad.tools.containertools.delete_contents_of_container_starting_at_or_after_offset.delete_contents_of_container_starting_at_or_after_offset
   :noindex:
